@@ -80,7 +80,9 @@ var knownPrefixedFiles = newStringSet(
 	Prefix+".toml"+TemplateSuffix,
 	Prefix+".yaml"+TemplateSuffix,
 	RootName,
-	dataName,
+	dataName+".json",
+	dataName+".toml",
+	dataName+".yaml",
 	externalName+".json",
 	externalName+".toml",
 	externalName+".yaml",
