@@ -5,6 +5,8 @@ import (
 	"os/exec"
 	"runtime"
 
+	"go.uber.org/multierr"
+
 	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
 )
 
@@ -21,11 +23,11 @@ type GPGEncryption struct {
 func (e *GPGEncryption) Decrypt(ciphertext []byte) ([]byte, error) {
 	var plaintext []byte
 	if err := withPrivateTempDir(func(tempDirAbsPath AbsPath) error {
-		ciphertextAbsPath := tempDirAbsPath.JoinStr("ciphertext" + e.EncryptedSuffix())
+		ciphertextAbsPath := tempDirAbsPath.JoinString("ciphertext" + e.EncryptedSuffix())
 		if err := os.WriteFile(ciphertextAbsPath.String(), ciphertext, 0o600); err != nil {
 			return err
 		}
-		plaintextAbsPath := tempDirAbsPath.Join("plaintext")
+		plaintextAbsPath := tempDirAbsPath.JoinString("plaintext")
 
 		args := e.decryptArgs(plaintextAbsPath, ciphertextAbsPath)
 		if err := e.run(args); err != nil {
@@ -44,7 +46,7 @@ func (e *GPGEncryption) Decrypt(ciphertext []byte) ([]byte, error) {
 // DecryptToFile implements Encryption.DecryptToFile.
 func (e *GPGEncryption) DecryptToFile(plaintextFilename AbsPath, ciphertext []byte) error {
 	return withPrivateTempDir(func(tempDirAbsPath AbsPath) error {
-		ciphertextAbsPath := tempDirAbsPath.JoinStr("ciphertext" + e.EncryptedSuffix())
+		ciphertextAbsPath := tempDirAbsPath.JoinString("ciphertext" + e.EncryptedSuffix())
 		if err := os.WriteFile(ciphertextAbsPath.String(), ciphertext, 0o600); err != nil {
 			return err
 		}
@@ -57,11 +59,11 @@ func (e *GPGEncryption) DecryptToFile(plaintextFilename AbsPath, ciphertext []by
 func (e *GPGEncryption) Encrypt(plaintext []byte) ([]byte, error) {
 	var ciphertext []byte
 	if err := withPrivateTempDir(func(tempDirAbsPath AbsPath) error {
-		plaintextAbsPath := tempDirAbsPath.Join("plaintext")
+		plaintextAbsPath := tempDirAbsPath.JoinString("plaintext")
 		if err := os.WriteFile(plaintextAbsPath.String(), plaintext, 0o600); err != nil {
 			return err
 		}
-		ciphertextAbsPath := tempDirAbsPath.JoinStr("ciphertext" + e.EncryptedSuffix())
+		ciphertextAbsPath := tempDirAbsPath.JoinString("ciphertext" + e.EncryptedSuffix())
 
 		args := e.encryptArgs(plaintextAbsPath, ciphertextAbsPath)
 		if err := e.run(args); err != nil {
@@ -81,7 +83,7 @@ func (e *GPGEncryption) Encrypt(plaintext []byte) ([]byte, error) {
 func (e *GPGEncryption) EncryptFile(plaintextFilename AbsPath) ([]byte, error) {
 	var ciphertext []byte
 	if err := withPrivateTempDir(func(tempDirAbsPath AbsPath) error {
-		ciphertextAbsPath := tempDirAbsPath.JoinStr("ciphertext" + e.EncryptedSuffix())
+		ciphertextAbsPath := tempDirAbsPath.JoinString("ciphertext" + e.EncryptedSuffix())
 
 		args := e.encryptArgs(plaintextFilename, ciphertextAbsPath)
 		if err := e.run(args); err != nil {
@@ -140,17 +142,20 @@ func (e *GPGEncryption) run(args []string) error {
 }
 
 // withPrivateTempDir creates a private temporary and calls f.
-func withPrivateTempDir(f func(tempDirAbsPath AbsPath) error) error {
-	tempDir, err := os.MkdirTemp("", "chezmoi-encryption")
-	if err != nil {
-		return err
+func withPrivateTempDir(f func(tempDirAbsPath AbsPath) error) (err error) {
+	var tempDir string
+	if tempDir, err = os.MkdirTemp("", "chezmoi-encryption"); err != nil {
+		return
 	}
-	defer os.RemoveAll(tempDir)
+	defer func() {
+		err = multierr.Append(err, os.RemoveAll(tempDir))
+	}()
 	if runtime.GOOS != "windows" {
-		if err := os.Chmod(tempDir, 0o700); err != nil {
-			return err
+		if err = os.Chmod(tempDir, 0o700); err != nil {
+			return
 		}
 	}
 
-	return f(NewAbsPath(tempDir))
+	err = f(NewAbsPath(tempDir))
+	return
 }
