@@ -1053,9 +1053,7 @@ func (s *SourceState) addPatterns(patternSet *patternSet, sourceAbsPath AbsPath,
 	for scanner.Scan() {
 		lineNumber++
 		text := scanner.Text()
-		if index := strings.IndexRune(text, '#'); index != -1 {
-			text = text[:index]
-		}
+		text, _, _ = CutString(text, "#")
 		text = strings.TrimSpace(text)
 		if text == "" {
 			continue
@@ -1897,7 +1895,7 @@ func (s *SourceState) readVersionFile(sourceAbsPath AbsPath) error {
 	}
 	version, err := semver.NewVersion(strings.TrimSpace(string(data)))
 	if err != nil {
-		return err
+		return fmt.Errorf("%s: %q: %w", sourceAbsPath, data, err)
 	}
 	var zeroVersion semver.Version
 	if s.version != zeroVersion && s.version.LessThan(*version) {
