@@ -143,7 +143,7 @@ type Config struct {
 	purge           purgeCmdConfig
 	reAdd           reAddCmdConfig
 	remove          removeCmdConfig
-	secretKeyring   secretKeyringCmdConfig
+	secret          secretCmdConfig
 	state           stateCmdConfig
 	status          statusCmdConfig
 	update          updateCmdConfig
@@ -279,6 +279,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		},
 		Onepassword: onepasswordConfig{
 			Command: "op",
+			Prompt:  true,
 		},
 		Pass: passConfig{
 			Command: "pass",
@@ -440,6 +441,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		"onepasswordItemFields":    c.onepasswordItemFieldsTemplateFunc,
 		"output":                   c.outputTemplateFunc,
 		"pass":                     c.passTemplateFunc,
+		"passFields":               c.passFieldsTemplateFunc,
 		"passRaw":                  c.passRawTemplateFunc,
 		"secret":                   c.secretTemplateFunc,
 		"secretJSON":               c.secretJSONTemplateFunc,
@@ -449,12 +451,6 @@ func newConfig(options ...configOption) (*Config, error) {
 	} {
 		c.addTemplateFunc(key, value)
 	}
-	for _, releaseTag := range build.Default.ReleaseTags {
-		if releaseTag == "go1.17" {
-			c.addTemplateFunc("exit", c.exitTemplateFunc)
-			break
-		}
-	}
 
 	for _, option := range options {
 		if err := option(c); err != nil {
@@ -717,13 +713,20 @@ func (c *Config) createAndReloadConfigFile() error {
 func (c *Config) createConfigFile(filename chezmoi.RelPath, data []byte) ([]byte, error) {
 	funcMap := make(template.FuncMap)
 	chezmoi.RecursiveMerge(funcMap, c.templateFuncs)
-	chezmoi.RecursiveMerge(funcMap, map[string]interface{}{
-		"promptBool":    c.promptBool,
-		"promptInt":     c.promptInt,
-		"promptString":  c.promptString,
-		"stdinIsATTY":   c.stdinIsATTY,
+	initTemplateFuncs := map[string]interface{}{
+		"promptBool":    c.promptBoolInitTemplateFunc,
+		"promptInt":     c.promptIntInitTemplateFunc,
+		"promptString":  c.promptStringInitTemplateFunc,
+		"stdinIsATTY":   c.stdinIsATTYInitTemplateFunc,
 		"writeToStdout": c.writeToStdout,
-	})
+	}
+	for _, releaseTag := range build.Default.ReleaseTags {
+		if releaseTag == "go1.17" {
+			initTemplateFuncs["exit"] = c.exitInitTemplateFunc
+			break
+		}
+	}
+	chezmoi.RecursiveMerge(funcMap, initTemplateFuncs)
 
 	t, err := template.New(filename.String()).Funcs(funcMap).Parse(string(data))
 	if err != nil {
@@ -908,7 +911,7 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 
 	var hostname string
 	if rawHostname, err := os.Hostname(); err == nil {
-		hostname = strings.SplitN(rawHostname, ".", 2)[0]
+		hostname, _, _ = chezmoi.CutString(rawHostname, "=")
 	} else {
 		c.logger.Info().
 			Err(err).
@@ -1286,9 +1289,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	persistentFlags.Var(&c.configFormat, "config-format", "Set config file format")
 	persistentFlags.Var(&c.cpuProfile, "cpu-profile", "Write a CPU profile to path")
 	persistentFlags.BoolVar(&c.debug, "debug", c.debug, "Include debug information in output")
-	persistentFlags.BoolVarP(
-		&c.dryRun, "dry-run", "n", c.dryRun, "Do not make any modifications to the destination directory",
-	)
+	persistentFlags.BoolVarP(&c.dryRun, "dry-run", "n", c.dryRun, "Do not make any modifications to the destination directory") //nolint:lll
 	persistentFlags.BoolVar(&c.force, "force", c.force, "Make all changes without prompting")
 	persistentFlags.BoolVar(&c.gops, "gops", c.gops, "Enable gops agent")
 	persistentFlags.BoolVarP(&c.keepGoing, "keep-going", "k", c.keepGoing, "Keep going as far as possible after an error")
@@ -1379,7 +1380,7 @@ func (c *Config) newSourceState(
 	default:
 		minVersion, err := semver.NewVersion(strings.TrimSpace(string(data)))
 		if err != nil {
-			return nil, fmt.Errorf("%s: %w", versionAbsPath, err)
+			return nil, fmt.Errorf("%s: %q: %w", versionAbsPath, data, err)
 		}
 		var zeroVersion semver.Version
 		if c.version != zeroVersion && c.version.LessThan(*minVersion) {
@@ -1949,7 +1950,7 @@ func (c *Config) targetRelPathsBySourcePath(
 	return targetRelPaths, nil
 }
 
-// targetValidArgs returns completions for targets.
+// targetValidArgs returns target completions for toComplete given args.
 func (c *Config) targetValidArgs(
 	cmd *cobra.Command, args []string, toComplete string,
 ) ([]string, cobra.ShellCompDirective) {
@@ -1958,11 +1959,13 @@ func (c *Config) targetValidArgs(
 		cobra.CompErrorln(err.Error())
 		return nil, cobra.ShellCompDirectiveError
 	}
+
 	sourceState, err := c.newSourceState(cmd.Context())
 	if err != nil {
 		cobra.CompErrorln(err.Error())
 		return nil, cobra.ShellCompDirectiveError
 	}
+
 	var completions []string
 	if err := sourceState.ForEach(func(targetRelPath chezmoi.RelPath, sourceStateEntry chezmoi.SourceStateEntry) error {
 		completion := c.DestDirAbsPath.Join(targetRelPath).String()
@@ -1974,6 +1977,18 @@ func (c *Config) targetValidArgs(
 		cobra.CompErrorln(err.Error())
 		return nil, cobra.ShellCompDirectiveError
 	}
+
+	if !filepath.IsAbs(toComplete) {
+		wd, err := os.Getwd()
+		if err != nil {
+			cobra.CompErrorln(err.Error())
+			return nil, cobra.ShellCompDirectiveError
+		}
+		for i, completion := range completions {
+			completions[i] = strings.TrimPrefix(completion, wd+"/")
+		}
+	}
+
 	return completions, cobra.ShellCompDirectiveNoFileComp
 }
 
