@@ -4,6 +4,8 @@ import (
 	"bytes"
 	"fmt"
 	"os/exec"
+
+	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
 )
 
 type passConfig struct {
@@ -36,11 +38,19 @@ func (c *Config) passOutput(id string) []byte {
 }
 
 func (c *Config) passTemplateFunc(id string) string {
+	output, _, _ := chezmoi.CutBytes(c.passOutput(id), []byte{'\n'})
+	return string(bytes.TrimSpace(output))
+}
+
+func (c *Config) passFieldsTemplateFunc(id string) map[string]string {
 	output := c.passOutput(id)
-	if index := bytes.IndexByte(output, '\n'); index != -1 {
-		return string(output[:index])
+	result := make(map[string]string)
+	for _, line := range bytes.Split(output, []byte{'\n'}) {
+		if key, value, ok := chezmoi.CutBytes(line, []byte{':'}); ok {
+			result[string(bytes.TrimSpace(key))] = string(bytes.TrimSpace(value))
+		}
 	}
-	return string(output)
+	return result
 }
 
 func (c *Config) passRawTemplateFunc(id string) string {
