@@ -21,11 +21,12 @@ import (
 	"strings"
 
 	"github.com/coreos/go-semver/semver"
-	"github.com/google/go-github/v40/github"
+	"github.com/google/go-github/v41/github"
 	"github.com/spf13/cobra"
 	vfs "github.com/twpayne/go-vfs/v4"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
+	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
 )
 
 const (
@@ -245,20 +246,7 @@ func (c *Config) downloadURL(ctx context.Context, url string) ([]byte, error) {
 	if err != nil {
 		return nil, err
 	}
-	resp, err := httpClient.Do(req)
-	if resp != nil {
-		c.logger.Err(err).
-			Str("method", req.Method).
-			Int("statusCode", resp.StatusCode).
-			Str("status", resp.Status).
-			Stringer("url", req.URL).
-			Msg("HTTP")
-	} else {
-		c.logger.Err(err).
-			Str("method", req.Method).
-			Stringer("url", req.URL).
-			Msg("HTTP")
-	}
+	resp, err := chezmoilog.LogHTTPRequest(c.logger, httpClient, req)
 	if err != nil {
 		return nil, err
 	}
