@@ -36,17 +36,11 @@ func (c *Config) newVerifyCmd() *cobra.Command {
 }
 
 func (c *Config) runVerifyCmd(cmd *cobra.Command, args []string) error {
-	dryRunSystem := chezmoi.NewDryRunSystem(c.destSystem)
-	if err := c.applyArgs(cmd.Context(), dryRunSystem, c.DestDirAbsPath, args, applyArgsOptions{
+	errorOnWriteSystem := chezmoi.NewErrorOnWriteSystem(c.destSystem, chezmoi.ExitCodeError(1))
+	return c.applyArgs(cmd.Context(), errorOnWriteSystem, c.DestDirAbsPath, args, applyArgsOptions{
 		include:   c.verify.include.Sub(c.verify.exclude),
 		init:      c.verify.init,
 		recursive: c.verify.recursive,
 		umask:     c.Umask,
-	}); err != nil {
-		return err
-	}
-	if dryRunSystem.Modified() {
-		return chezmoi.ExitCodeError(1)
-	}
-	return nil
+	})
 }
